Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(475)

Unified Diff: src/udev.c

Issue 6673092: flimflam: Support all gobi devices. (Closed) Base URL: ssh://git@gitrw.chromium.org:9222/flimflam.git@master
Patch Set: Style police Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/udev.c
diff --git a/src/udev.c b/src/udev.c
index 3cfe47b1868cac43836b0e624d6c1acc5ff9e4e1..45f5bb9af894d89e50609885849cf149b08c2662 100644
--- a/src/udev.c
+++ b/src/udev.c
@@ -437,8 +437,13 @@ connman_bool_t __connman_udev_has_associated_modem(const char *ifname)
goto done;
driver = udev_device_get_driver(parent);
- if (g_strcmp0(driver, "QCUSBNet2k") == 0) {
- /* QCUSBNet2k is always associated with modems */
+ if (g_strcmp0(driver, "QCUSBNet2k") == 0 ||
+ g_strcmp0(driver, "GobiNet") == 0 ||
+ g_strcmp0(driver, "gobi") == 0) {
+ /*
+ * This family of drivers is always associated with Gobi 3G
+ * modems.
+ */
has_modem = TRUE;
goto done;
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698